@@ -1,5 +1,4 @@
-# $Id: Checkout.pm 1441 2006-09-27 02:48:09Z claco $
-## no critic
+# $Id: Checkout.pm 768 2005-09-05 02:25:24Z claco $
 package AxKit::XSP::Handel::Checkout;
 use strict;
 use warnings;
@@ -43,8 +42,8 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Checkout';
 
         if ($tag eq 'new') {
             throw Handel::Exception::Taglib(
-                -text => translate('TAG_NOT_ALLOWED_IN_OTHERS', $tag)
-            ) if ($context[-1] ne 'root');
+                -text => translate("Tag '[_1]' not valid inside of other Handel tags", $tag)
+            ) if ($context[$#context] ne 'root');
 
             push @context, $tag;
 
@@ -68,8 +67,8 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Checkout';
             return $code;
         } elsif ($tag eq 'plugin') {
             throw Handel::Exception::Taglib(
-                -text => translate('Tag [_1] not valid inside of tag [_2]', $tag, $context[-1])
-            ) if ($context[-1] ne 'plugins');
+                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[$#context] . "'", $tag)
+            ) if ($context[$#context] ne 'plugins');
 
             push @context, $tag;
 
@@ -96,8 +95,8 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Checkout';
             undef $property if ($property eq 'checkout');
 
             throw Handel::Exception::Taglib(
-                -text => translate('Tag [_1] not valid inside of tag [_2]', $tag, $context[-1])
-            ) if ($context[-1] ne 'messages');
+                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[$#context] . "'", $tag)
+            ) if ($context[$#context] ne 'messages');
 
             push @context, $tag;
 
@@ -135,8 +134,8 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Checkout';
             return $code;
         } elsif ($tag eq 'phase') {
             throw Handel::Exception::Taglib(
-                -text => translate('Tag [_1] not valid inside of tag [_2]', $tag, $context[-1])
-            ) if ($context[-1] ne 'phases');
+                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[$#context] . "'", $tag)
+            ) if ($context[$#context] ne 'phases');
 
             push @context, $tag;
 
@@ -420,7 +419,7 @@ the orders uuid value:
 
 =head2 <checkout:ok>
 
-If process succeeds, anything in the ok block is run:
+If process suceeds, anything in the ok block is run:
 
     <checkout:new>
         <checkout:process>
