@@ -1,4 +1,4 @@
-# $Id: Second.pm 1487 2006-10-19 02:56:29Z claco $
+# $Id: Second.pm 837 2005-09-19 22:56:39Z claco $
 package Handel::OtherTestPlugins::Second;
 use strict;
 use warnings;
@@ -9,7 +9,7 @@ sub register {
     my ($self, $ctx) = @_;
 
     $self->{'register_called'}++;
-    $ctx->add_handler(CHECKOUT_PHASE_INITIALIZE, \&handler, 2);
+    $ctx->add_handler(CHECKOUT_PHASE_INITIALIZE, \&handler);
 };
 
 sub init {
@@ -35,7 +35,7 @@ sub handler {
 
     $self->{'handler_called'}++;
 
-    return CHECKOUT_HANDLER_DECLINE;
+    return CHECKOUT_HANDLER_OK;
 };
 
-1;
+1;
\ No newline at end of file
